Cave Story (Items)

- Items -
* Field Items

| Disk | Saves your game.
| Energy | Collect these to level-up your weapon.
| Life | Restores your health.
| Missile | Restores your missile ammunition.
| Server | Fully restores your health and ammunition.
| Life Capsule | Increases your maximum health.
| Treasure Chest | All kinds of goodies lurk inside.

(There are many others.)
* Event Items

| Map System | Displays a map of the current stage.
| Silver Locket | Someone's pendant.
| Arthur's Key | A key to open a door somewhere.

(For more details, try the game.)